@@ -9,20 +9,18 @@
 #include "context.h"
 #include "ime.h"
 #include "state.h"
-#include <boost/algorithm/string.hpp>
-#include <boost/iostreams/device/file_descriptor.hpp>
-#include <boost/iostreams/stream.hpp>
-#include <boost/iostreams/stream_buffer.hpp>
 #include <cstddef>
 #include <exception>
 #include <fcitx-config/iniparser.h>
 #include <fcitx-config/rawconfig.h>
 #include <fcitx-utils/charutils.h>
 #include <fcitx-utils/event.h>
+#include <fcitx-utils/eventloopinterface.h>
+#include <fcitx-utils/fdstreambuf.h>
 #include <fcitx-utils/i18n.h>
 #include <fcitx-utils/log.h>
 #include <fcitx-utils/macros.h>
-#include <fcitx-utils/standardpath.h>
+#include <fcitx-utils/standardpaths.h>
 #include <fcitx-utils/stringutils.h>
 #include <fcitx-utils/utf8.h>
 #include <fcitx/action.h>
@@ -37,6 +35,7 @@
 #include <fcitx/statusarea.h>
 #include <fcitx/userinterfacemanager.h>
 #include <fcntl.h>
+#include <filesystem>
 #include <istream>
 #include <libime/core/historybigram.h>
 #include <libime/core/languagemodel.h>
@@ -127,14 +126,11 @@ void TableEngine::populateConfig() {
     std::unique_ptr<libime::ShuangpinProfile> shuangpinProfile;
 
     if (*config_.shuangpinProfile == LookupShuangpinProfileEnum::Custom) {
-        auto file = StandardPath::global().open(StandardPath::Type::PkgConfig,
-                                                "pinyin/sp.dat", O_RDONLY);
+        auto file = StandardPaths::global().open(StandardPathsType::PkgConfig,
+                                                 "pinyin/sp.dat");
         if (file.isValid()) {
             try {
-                boost::iostreams::stream_buffer<
-                    boost::iostreams::file_descriptor_source>
-                    buffer(file.fd(), boost::iostreams::file_descriptor_flags::
-                                          never_close_handle);
+                IFDStreamBuf buffer(file.fd());
                 std::istream in(&buffer);
                 shuangpinProfile =
                     std::make_unique<libime::ShuangpinProfile>(in);
@@ -279,23 +275,18 @@ const libime::PinyinDictionary &TableEngine::pinyinDict() {
                       libime::PinyinDictionary::UserDict + 1);
         for (size_t i = 0; i < FCITX_ARRAY_SIZE(dicts); i++) {
             try {
-                const auto &standardPath = StandardPath::global();
+                const auto &standardPath = StandardPaths::global();
                 auto systemDictFile = standardPath.open(
-                    StandardPath::Type::Data,
-                    stringutils::joinPath("libime", dicts[i]), O_RDONLY);
+                    StandardPathsType::Data,
+                    std::filesystem::path("libime") / dicts[i]);
                 if (!systemDictFile.isValid()) {
                     systemDictFile = standardPath.open(
-                        StandardPath::Type::Data,
-                        stringutils::joinPath(LIBIME_INSTALL_PKGDATADIR,
-                                              dicts[i]),
-                        O_RDONLY);
+                        StandardPathsType::Data,
+                        std::filesystem::path(LIBIME_INSTALL_PKGDATADIR) /
+                            dicts[i]);
                 }
 
-                boost::iostreams::stream_buffer<
-                    boost::iostreams::file_descriptor_source>
-                    buffer(systemDictFile.fd(),
-                           boost::iostreams::file_descriptor_flags::
-                               never_close_handle);
+                IFDStreamBuf buffer(systemDictFile.fd());
                 std::istream in(&buffer);
                 pinyinDict_.load(i, in, libime::PinyinDictFormat::Binary);
             } catch (const std::exception &e) {
