@@ -16,6 +16,7 @@
 #include <fcitx-utils/eventdispatcher.h>
 #include <fcitx-utils/i18n.h>
 #include <fcitx-utils/misc.h>
+#include <fcitx-utils/trackableobject.h>
 #include <fcitx/addonfactory.h>
 #include <fcitx/addoninstance.h>
 #include <fcitx/instance.h>
@@ -51,7 +52,8 @@ public:
     virtual ~Backend() = default;
 };
 
-class CloudPinyin : public fcitx::AddonInstance {
+class CloudPinyin : public fcitx::AddonInstance,
+                    public fcitx::TrackableObject<CloudPinyin> {
 public:
     CloudPinyin(fcitx::AddonManager *manager);
     ~CloudPinyin() override;
@@ -80,7 +82,7 @@ private:
     FCITX_ADDON_EXPORT_FUNCTION(CloudPinyin, resetError);
     std::unique_ptr<FetchThread> thread_;
     fcitx::EventLoop *eventLoop_;
-    fcitx::EventDispatcher dispatcher_;
+    fcitx::EventDispatcher &dispatcher_;
     std::unique_ptr<fcitx::EventSourceIO> event_;
     std::unique_ptr<fcitx::EventSourceTime> resetError_;
     LRUCache<std::string, std::string> cache_{2048};
