@@ -16,7 +16,7 @@
 #include <fcitx-utils/keysym.h>
 #include <fcitx-utils/log.h>
 #include <fcitx-utils/macros.h>
-#include <fcitx-utils/standardpath.h>
+#include <fcitx-utils/standardpaths.h>
 #include <fcitx-utils/testing.h>
 #include <fcitx/addonmanager.h>
 #include <fcitx/inputmethodgroup.h>
@@ -492,13 +492,10 @@ void testPunctuationPart2(Instance *instance) {
 
 int main() {
     setupTestingEnvironment(
-        TESTING_BINARY_DIR,
-        {TESTING_BINARY_DIR "/modules/pinyinhelper",
-         TESTING_BINARY_DIR "/modules/punctuation",
-         TESTING_BINARY_DIR "/im/pinyin"},
+        TESTING_BINARY_DIR, {"bin"},
         {TESTING_BINARY_DIR "/test", TESTING_BINARY_DIR "/im",
          TESTING_BINARY_DIR "/modules", TESTING_SOURCE_DIR "/modules",
-         StandardPath::fcitxPath("pkgdatadir")});
+         StandardPaths::fcitxPath("pkgdatadir")});
     // fcitx::Log::setLogRule("default=5,table=5,libime-table=5");
     char arg0[] = "testpinyin";
     char arg1[] = "--disable=all";
